Documentation
¶
Index ¶
- func CreateContent(c *fiber.Ctx) error
- func CreateContentType(c *fiber.Ctx) error
- func CreateRole(c *fiber.Ctx) error
- func CreateUser(c *fiber.Ctx) error
- func DeleteContent(c *fiber.Ctx) error
- func DeleteContentType(c *fiber.Ctx) error
- func DeleteRole(c *fiber.Ctx) error
- func DeleteUser(c *fiber.Ctx) error
- func GetAllContentTypes(c *fiber.Ctx) error
- func GetContent(c *fiber.Ctx) error
- func GetContentType(c *fiber.Ctx) error
- func GetRoles(c *fiber.Ctx) error
- func GetUsers(c *fiber.Ctx) error
- func Healthcheck(c *fiber.Ctx) error
- func Login(c *fiber.Ctx) error
- func UpdateContent(c *fiber.Ctx) error
- func UpdateContentType(c *fiber.Ctx) error
- func UpdateRole(c *fiber.Ctx) error
- func UpdateUser(c *fiber.Ctx) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CreateContent ¶
CreateContent new content Collection is created by mongoDB automatically on first insert call
func DeleteRole ¶
DeleteRole delete role with provided role name
func GetAllContentTypes ¶
GetAll query all Content Types
func GetContent ¶
Query content entries with filter provided in query params
func GetContentType ¶
GetContentType query contenttypes by ID
func Healthcheck ¶
func UpdateContent ¶
Update content entry with parameters from request body Update user with parameters from request body
func UpdateContentType ¶
Update content type with parameters from request body
func UpdateRole ¶
Update role with parameters from request body lookup by: role field to update: weight
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.